import 'package:flutter/material.dart';

import 'settings_controller.dart';

/// Displays the various settings that can be customized by the user.
///
/// When a user changes a setting, the SettingsController is updated and
/// Widgets that listen to the SettingsController are rebuilt.
class SettingsView extends StatelessWidget {
  const SettingsView({Key? key, required this.controller}) : super(key: key);

  static const routeName = '/settings';

  final SettingsController controller;

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        leading: IconButton(
          key: const Key('settingsBackButton'),
          icon: const Icon(Icons.arrow_back),
          onPressed: () {
            Navigator.pop(context);
          },
        ),
        title: const Text('Settings'),
      ),
      body: Padding(
        padding: const EdgeInsets.all(16),
        // Glue the SettingsController to the theme selection DropdownButton.
        //
        // When a user selects a theme from the dropdown list, the
        // SettingsController is updated, which rebuilds the MaterialApp.
        child: DropdownButton<ThemeMode>(
          key: const Key('screenModeDropdown'),
          // Read the selected themeMode from the controller
          value: controller.themeMode,
          // Call the updateThemeMode method any time the user selects a theme.
          onChanged: controller.updateThemeMode,
          items: const [
            DropdownMenuItem(
              key: Key('systemMode'),
              value: ThemeMode.system,
              child: Text('Telefoon kleuren', key: ValueKey(1)),
            ),
            DropdownMenuItem(
              key: Key('lightMode'),
              value: ThemeMode.light,
              child: Text('Lichte kleuren', key: ValueKey(2)),
            ),
            DropdownMenuItem(
              key: Key('darkMode'),
              value: ThemeMode.dark,
              child: Text('Donkere kleuren', key: ValueKey(3)),
            )
          ],
        ),
      ),
    );
  }
}
