//TODO: introduce mocking
import 'package:cramr_ui_lib/model/study_mode.dart';
import 'package:cramr_ui_lib/model/study_mode_state.dart';
import 'package:cramr_ui_lib/model/verb_test_model.dart';
import 'package:cramr_ui_lib/routes/verb_indicative_study_cover_mode_route.dart';
import 'package:cramr_ui_lib/settings/settings_controller.dart';
import 'package:cramr_ui_lib/settings/settings_service.dart';
import 'package:flutter/material.dart';
import 'package:flutter_test/flutter_test.dart';
import 'package:provider/provider.dart';

final List<String> _randomIndicative = [
  'exp1',
  'exp2',
  'exp3',
  'exp4',
  'exp5',
  'exp6',
];

final List<String> _randomPronouns = [
  'pron1',
  'pron2',
  'pron3',
  'pron4',
  'pron5',
  'pron6',
];

const String _randomInfinitive = 'infinitive';

void main() {
  testWidgets('Testing for the presence of covered buttons',
      (WidgetTester tester) async {
    await tester.pumpWidget(MultiProvider(
        providers: [
          ChangeNotifierProvider(create: (BuildContext context) {
            var model = VerbTestModel();
            model.initialise(_randomIndicative, _randomPronouns, 'fr',
                'infinitive', 'translation');
            return model;
          }),
          ChangeNotifierProvider(create: (BuildContext context) {
            return StudyModeState(StudyMode.flashCardMode);
          })
        ],
        child: VerbIndicativeStudyCoverModeRoute(
          SettingsController(SettingsService(), ThemeMode.dark),
          key: UniqueKey(),
        )));
    final Finder translationFinder = find.text("translation");
    expect(translationFinder, findsOneWidget);
    for (int i = 0; i < 6; i++) {
      // Make sure that we cannot read the indicative yet
      final Finder indicativeFinder = find.text(_randomIndicative[i]);
      expect(indicativeFinder, findsNothing);

      // Check if we can find the cover
      final Finder coverFinder =
          find.byKey(Key('coverkey_${_randomInfinitive}_$i'));
      expect(coverFinder, findsOneWidget);

      // Make sure that we can read the indicative after tapping it
      await tester.tap(coverFinder);
      await tester.pump();
      expect(indicativeFinder, findsOneWidget);
    }
  });
}
